@@ -55,25 +55,35 @@ def createFiles(projectname: str, cli: bool, python_version: str):
         'hashes': '##'
     }
 
-    standard = [
+    project = [
         '.env',
         '.flake8',
         '.gitignore',
         '.gitlab-ci.yml',
         '.style.yapf',
-        'deploy.sh',
-        'Pipfile',
         'README.md',
+        'Pipfile',
         'VERSION',
         'pytest.ini',
     ]
 
-    for tmpl in standard:
-        writeTemplate(tmpl, PROJECT_ROOT, data=data)
+    for tmpl in project:
+        writeTemplate(tmpl, PROJECT_ROOT, data=data, templatepath='project')
 
-    writeTemplate('settings.json', PROJECT_ROOT / '.vscode', data=data)
-    writeTemplate('extensions.json', PROJECT_ROOT / '.vscode', data=data)
+    vscode = [
+        'launch.json',
+        'settings.json',
+        'extensions.json',
+    ]
+    for tmpl in vscode:
+        writeTemplate(tmpl, PROJECT_ROOT / '.vscode', data=data, templatepath='vscode')
 
-    pkg_tmpl = ['LICENSE', 'setup.cfg', 'pyproject.toml', 'MANIFEST.in']
-    for tmpl in pkg_tmpl:
-        writeTemplate(tmpl, PROJECT_ROOT, data=data)
+    package = [
+        'LICENSE',
+        'setup.cfg',
+        'pyproject.toml',
+        'MANIFEST.in',
+        'deploy.sh',
+    ]
+    for tmpl in package:
+        writeTemplate(tmpl, PROJECT_ROOT, data=data, templatepath='package')
