@@ -11,7 +11,8 @@ cli = False
 python_version = '3.8'
 
 TEST_DIR = DIR.parent / projectname
-PROJ_DIR = TEST_DIR / 'src' / projectname.replace('-', '_')
+PROJ_SRC = TEST_DIR / 'src'
+PROJ_DIR = PROJ_SRC / projectname.replace('-', '_')
 
 
 def test_copy_templates():
@@ -19,7 +20,7 @@ def test_copy_templates():
         shutil.rmtree(TEST_DIR)
     assert not TEST_DIR.exists(), f"{TEST_DIR} should not exist"
     copyTemplates(projectname, cli)
-    assert (PROJ_DIR / '_config' /
+    assert (PROJ_SRC / '_config' /
             'logging.yaml').exists(), f'logging.yaml not copied to {PROJ_DIR}'
 
 
